pub struct PolicyManager { /* private fields */ }Expand description
Thread-safe policy manager backed by persistent storage.
Implementations
Sourceimpl PolicyManager
impl PolicyManager
pub fn new() -> Self
Sourcepub fn load(store: &TensorStore) -> Self
pub fn load(store: &TensorStore) -> Self
Load policies from storage.
Sourcepub fn add_policy(
&self,
store: &TensorStore,
template: PolicyTemplate,
) -> Result<()>
pub fn add_policy( &self, store: &TensorStore, template: PolicyTemplate, ) -> Result<()>
Add or update a policy template.
Sourcepub fn remove_policy(&self, store: &TensorStore, name: &str) -> Result<()>
pub fn remove_policy(&self, store: &TensorStore, name: &str) -> Result<()>
Remove a policy template.
Sourcepub fn list_policies(&self) -> Vec<PolicyTemplate>
pub fn list_policies(&self) -> Vec<PolicyTemplate>
List all policy templates.
Sourcepub fn get_policy(&self, name: &str) -> Option<PolicyTemplate>
pub fn get_policy(&self, name: &str) -> Option<PolicyTemplate>
Get a specific policy by name.
Sourcepub fn evaluate_policies(&self, entity: &str) -> Vec<PolicyMatch>
pub fn evaluate_policies(&self, entity: &str) -> Vec<PolicyMatch>
Evaluate all policies for a given entity, returning matching policies.
Sourcepub fn check_policy_access(
&self,
entity: &str,
secret_key: &str,
) -> Option<(Permission, Option<i64>)>
pub fn check_policy_access( &self, entity: &str, secret_key: &str, ) -> Option<(Permission, Option<i64>)>
Check if any policy grants the entity access to a specific secret.